@@ -6,27 +6,37 @@ from typing import Union, Any
 
 
 
+JSONValue = Union[None, bool, int, str, 'JSONObject']
+JSONObject = list[JSONValue] | dict[str, JSONValue]
+
+
 class LazyJSON:
-    """A wrapper for a JSON object
+    """
+    A wrapper for a JSON object
     that only loads entries on request
 
-    OBS! This is meant as read-only
+    OBS! This is meant as read-only.
     """
 
-    data: Union[list, dict]
+    data: JSONObject
 
-    def __init__(self, data: Union[list, dict]):
+
+    def __init__(self, data: JSONObject) -> None:
         self.data = data
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.data)
 
     @cache
-    def __getitem__(self, key: Union[int, str]):
+    def __getitem__(self, key: Union[int, str]) -> JSONValue:
         return loads(self.data[key])
 
 
-    def get(self, key: Union[int, str], default: Any = None):
+    def get(self, key: Union[int, str], default: Any = None) -> JSONValue:
+        """
+        Return the value for key if key is in the dictionary, else default.
+        """
+        
         if isinstance(key, int):
             with suppress(IndexError):
                 return self[key]
@@ -38,7 +48,15 @@ class LazyJSON:
         return default
 
 
-def loads(data: Union[None, bool, int, str, list, dict]):
+def loads(data: JSONValue) -> LazyJSON | JSONValue:
+    """
+    Parse data into a lazy loading JSON object.
+
+    The value will be returned as is,
+    if it is not a list or dictionary,
+    or a string that can be interpreted as JSON.
+    """
+
     # Lists and dictionaries can be used for `LazyJSON`
     if isinstance(data, (list, dict)):
         return LazyJSON(data)
